@@ -2,7 +2,7 @@
 import sys
 
 
-__version__ = '4.3.0'
+__version__ = '4.5.1'
 
 API_PATH = {
     'about_edited':           'r/{subreddit}/about/edited/',
@@ -24,7 +24,9 @@ API_PATH = {
     'contest_mode':           'api/set_contest_mode/',
     'del':                    'api/del/',
     'deleteflair':            'r/{subreddit}/api/deleteflair',
+    'delete_sr_banner':       'r/{subreddit}/api/delete_sr_banner',
     'delete_sr_header':       'r/{subreddit}/api/delete_sr_header',
+    'delete_sr_icon':         'r/{subreddit}/api/delete_sr_icon',
     'delete_sr_image':        'r/{subreddit}/api/delete_sr_img',
     'distinguish':            'api/distinguish/',
     'domain':                 'domain/{domain}/',
@@ -60,11 +62,18 @@ API_PATH = {
     'live_add_update':        'api/live/{id}/update',
     'live_close':             'api/live/{id}/close_thread',
     'live_contributors':      'live/{id}/contributors',
+    'live_discussions':       'live/{id}/discussions',
+    'live_info':              'api/live/by_id/{ids}',
     'live_invite':            'api/live/{id}/invite_contributor',
     'live_leave':             'api/live/{id}/leave_contributor',
+    'live_now':               'api/live/happening_now',
     'live_remove_update':     'api/live/{id}/delete_update',
     'live_remove_contrib':    'api/live/{id}/rm_contributor',
     'live_remove_invite':     'api/live/{id}/rm_contributor_invite',
+    'live_report':            'api/live/{id}/report',
+    'live_strike':            'api/live/{id}/strike_update',
+    'live_update_perms':      'api/live/{id}/set_contributor_permissions',
+    'live_update_thread':     'api/live/{id}/edit',
     'live_updates':           'live/{id}',
     'liveabout':              'api/live/{id}/about/',
     'livecreate':             'api/live/create',
@@ -81,6 +90,18 @@ API_PATH = {
     'my_multireddits':        'api/multi/mine/',
     'my_subreddits':          'subreddits/mine/subscriber/',
     'marknsfw':               'api/marknsfw/',
+    'modmail_archive':        'api/mod/conversations/{id}/archive',
+    'modmail_bulk_read':      'api/mod/conversations/bulk/read',
+    'modmail_conversation':   'api/mod/conversations/{id}',
+    'modmail_conversations':  'api/mod/conversations/',
+    'modmail_highlight':      'api/mod/conversations/{id}/highlight',
+    'modmail_mute':           'api/mod/conversations/{id}/mute',
+    'modmail_read':           'api/mod/conversations/read',
+    'modmail_subreddits':     'api/mod/conversations/subreddits',
+    'modmail_unarchive':      'api/mod/conversations/{id}/unarchive',
+    'modmail_unmute':         'api/mod/conversations/{id}/unmute',
+    'modmail_unread':         'api/mod/conversations/unread',
+    'modmail_unread_count':   'api/mod/conversations/unread/count',
     'multireddit':            'user/{user}/m/{multi}/',
     'multireddit_api':        'api/multi/user/{user}/m/{multi}/',
     'multireddit_base':       'api/multi/',
